@@ -1,6 +1,6 @@
 ;;; helm-locate.el --- helm interface for locate. -*- lexical-binding: t -*-
 
-;; Copyright (C) 2012 ~ 2016 Thierry Volpiatto <thierry.volpiatto@gmail.com>
+;; Copyright (C) 2012 ~ 2017 Thierry Volpiatto <thierry.volpiatto@gmail.com>
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -62,9 +62,9 @@ This string will be passed to format so it should end with `%s'.
 The first format spec is used for the \"-i\" value of locate/es,
 So don't set it directly but use `helm-locate-case-fold-search'
 for this.
-The \"-r\" option must be the last option, however if not specified you will
-be able to specify it during helm invocation by prefixing the pattern
-you enter with \"-r\"."
+The last option must be the one preceding pattern i.e \"-r\" or \"--regex\".
+You will be able to pass other options such as \"-b\" or \"l\"
+during helm invocation after entering pattern."
   :type 'string
   :group 'helm-locate)
 
