@@ -1,6 +1,6 @@
 ;;; helm-source.el --- Helm source creation. -*- lexical-binding: t -*-
 
-;; Copyright (C) 2015 ~ 2016  Thierry Volpiatto <thierry.volpiatto@gmail.com>
+;; Copyright (C) 2015 ~ 2017  Thierry Volpiatto <thierry.volpiatto@gmail.com>
 
 ;; Author: Thierry Volpiatto <thierry.volpiatto@gmail.com>
 ;; URL: http://github.com/emacs-helm/helm
@@ -381,7 +381,10 @@
   sources built with child class `helm-source-in-buffer' the SEARCH slot.
   This is an easy way of enabling fuzzy matching, but you can use the MATCH
   or SEARCH slots yourself if you want something more elaborated, mixing
-  different type of match (See `helm-source-buffers' class for example).")
+  different type of match (See `helm-source-buffers' class for example).
+
+  This attribute is not supported for asynchronous sources
+  since they perform pattern matching themselves.")
 
    (nomark
     :initarg :nomark
@@ -809,9 +812,10 @@ an eieio class."
                                (helm-append-at-nth
                                 actions new-action index))
                               (t actions)))))
-    (if (functionp actions)
-        (setf (slot-value source 'action) (list (cons "Default action" actions)))
-        (setf (slot-value source 'action) (helm-interpret-value actions source)))
+    (cond ((functionp actions)
+           (setf (slot-value source 'action) (list (cons "Default action" actions))))
+          ((listp actions)
+           (setf (slot-value source 'action) (helm-interpret-value actions source))))
     (when (or (symbolp action-transformers) (functionp action-transformers))
       (setq action-transformers (list action-transformers)))
     (setf (slot-value source 'action-transformer)
@@ -944,7 +948,9 @@ an eieio class."
   (cl-assert (null (slot-value source 'candidates))
              nil "Incorrect use of `candidates' use `candidates-process' instead")
   (cl-assert (null (slot-value source 'multimatch))
-             nil "`multimatch' not allowed in async sources."))
+             nil "`multimatch' not allowed in async sources.")
+  (cl-assert (null (slot-value source 'fuzzy-match))
+             nil "`fuzzy-match' not supported in async sources."))
 
 (defmethod helm--setup-source ((source helm-source-dummy))
   (let ((mtc (slot-value source 'match)))
